//"ius_BaudRateUseTimer" -> "ius_BaudRateUseTimer"
//====================================================================
//IUS51(In User's System for uProbe51) options
//Copyright @2006 DEEMAX Electronics, Inc.
//							version 1.00
//====================================================================

//====================================================================
//Timer selection:
//Select the timer used as baud rates generator 
#define ius_BaudRateUseTimer	1	//1: Use timer 1 to generate baud rates
								//2: Use timer 2 to generate baud rates
//Error detector(DO NOT EDIT)
#if (ius_BaudRateUseTimer<=0 || ius_BaudRateUseTimer>2)
  >>>Error: //Only timer1, or timer2 is allowed as baudrate generator
#endif
//====================================================================

//====================================================================
//Frequency of the system clock:
//Note the frequency value must match the system using.
//#define ius_SYSTEM_CLOCK	11059200UL //Hz unit
#define   ius_SYSTEM_CLOCK	22118400UL //Hz unit
//#define ius_SYSTEM_CLOCK   33177600UL //Hz unit
//====================================================================

//====================================================================
//Baud rates supporting:
//Comment the definition to prune away the baud rates supporting
//#define ius_BR230400	230400UL
#define ius_BR115200	115200UL
#define ius_BR57600		57600UL
#define ius_BR38400		38400UL
#define ius_BR19200		19200UL
#define ius_BR9600		9600UL
#define ius_BR4800		4800UL

//Error detector(DO NOT EDIT)
#ifndef ius_BR9600
  >>>Error: //BR9600 is the based baud rates. It must be defined.
#endif
//====================================================================

//====================================================================
//Available tolerant percentage of the baud rates:
//	availabe range 0~2(0%~2%)
#define ius_AVAILABLE_tolerancy	0U

//Error detector(DO NOT EDIT)
#if ius_AVAILABLE_tolerancy >= 3U
  >>>Error: //ius_tolerancy should less than 3
#endif
//====================================================================

//====================================================================
//Serial Interrupt Priority Macro
//====================================================================
#define SET_SERIAL_INT_PRIORITY	PS=1;
//====================================================================


//==========================================================================
//IUS51 Stack Length:
//	IUS51 system require at least 12 bytes stack length.
//  Stack reserved 16 bytes for system and user's export functions
//	requirement.
//	User may modify STACK_LEN definition if the export functions
//  require more stack buffer.
//
//IUS memory scheme(IDATA):
//	0-->                                       |->0x70
//	-----------------------------------------------------------------------
//	|    System Data     |    Stack Buffer     | Never used by IUS system |
//	-----------------------------------------------------------------------
//	|<- sizeof(System Data)+STACK_LEN ->|^-----User's data from here
//
//==========================================================================
#define STACK_LEN	16
//Error detector(DO NOT EDIT)
#if STACK_LEN<12
  >>>Error: //STACK_LEN should great than 12
#endif

//====================================================================
//Serial Time-Base:
//  Serial port is IUS51 and Vision51 Transmission interface.
//  Timer1 or Timer2(depend on ius_BaudRateUseTimer setting) is used
//  as the UART baud rates generator.
//  To use Timer1 as baud rates generater:
//    For this purpose Timer1 is used in mode 2 (Auto-Reload).
//    Baud Rate = ius_SYSTEM_CLOCK/(iusSTBn*(256-TH1))
//  To use Timer2 as baud rates generator:
//    For this purpose Timer2 is used in Auto-Reload mode.
//    Baud Rate= ius_SYSTEM_CLOCK/(iusSTBn*(65536-RCAP2))
//    The iusSTBn(n can be 0~9) means "Serial Time-Base" thant need
//    defined at here.
//    Also each iusSTBn need define a corresponding iusSETUP_STBn macro.
//    to setup correct Serial Time-Base.
//    For example, the timer 1 of standard 8051 family counting at the
//    rate of 1/12 of the clock frequency.
//    The baud rates formula for serial port in mode 2 is:
//        Baud Rates= (k*ius_SYSTEM_CLOCK)/(32*12*(256-TH1))
//                  = ius_SYSTEM_CLOCK/((32*12/k)*(256-TH1))--->iusSTBn=(32*12/k)
//        Note K= SMOD+1(SMOD is bit 7 of the PCON register)
//        Here we need define two sets of iusSTBn/iusSETUP_STBn: 
//            #define iusSETUP_STB0		PCON &= 0x7F; //SMOD=0
//            #define iusSTB0			(32*12/1)
//            #define iusSETUP_STB1		PCON |= 0x80; //SMOD=1
//            #define iusSTB1			(32*12/2)
//    Macro "iusINIT_SERIAL" also need define here for serial initiation.
//--------------------------------------------------------------------
//Define each MCU as separated file and only one can be included,
//#include "MCU_std51.h"
#include "MCU_winbond77.h"
//#include "MCU_sl8051F30x.H"


